@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package JSON::Schema::Modern; # git description: v0.537-6-g440918d0
+package JSON::Schema::Modern; # git description: v0.538-6-g530f7cb5
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Validate data against a schema
 # KEYWORDS: JSON Schema data validation structure specification
 
-our $VERSION = '0.538';
+our $VERSION = '0.539';
 
 use 5.020;  # for fc, unicode_strings features
 use Moo;
@@ -923,7 +923,7 @@ JSON::Schema::Modern - Validate data against a schema
 
 =head1 VERSION
 
-version 0.538
+version 0.539
 
 =head1 SYNOPSIS
 
@@ -1077,7 +1077,7 @@ or a URI string indicating the location where such a schema is located.
 
 Optionally, a hashref can be passed as a third parameter which allows changing the values of the
 L</short_circuit>, L</collect_annotations>, L</annotate_unknown_keywords>, L</scalarref_booleans>,
-L</validate_formats>, and/or L<validate_content_schemas>
+L</validate_formats>, and/or L</validate_content_schemas>
 settings for just this evaluation call.
 
 The result is a L<JSON::Schema::Modern::Result> object, which can also be used as a boolean.
@@ -1112,7 +1112,7 @@ or a URI string indicating the location where such a schema is located.
 
 Optionally, a hashref can be passed as a third parameter which allows changing the values of the
 L</short_circuit>, L</collect_annotations>, L</annotate_unknown_keywords>, L</scalarref_booleans>,
-L</validate_formats>, and/or L<validate_content_schemas>
+L</validate_formats>, and/or L</validate_content_schemas>
 settings for just this evaluation call.
 
 You can pass a series of callback subs to this method corresponding to keywords, which is useful for
@@ -1496,8 +1496,6 @@ L<Understanding JSON Schema|https://json-schema.org/understanding-json-schema>:
 
 =back
 
-=head1 SUPPORT
-
 =for stopwords OpenAPI
 
 You can also find me on the L<JSON Schema Slack server|https://json-schema.slack.com> and L<OpenAPI Slack
